# -*- coding: utf-8 -*-
"""Logcheck recipe"""
import logging
import os

logger = logging.getLogger('logcheck')

NEEDED_SUBDIRS= ('cracking.d',
                 'cracking.ignore.d',
                 'violations.d',
                 'violations.ignore.d',
                 'ignore.d.paranoid',
                 'ignore.d.server',
                 'ignore.d.workstation')

CONF_TEMPLATE = '''
REPORTLEVEL="workstation"
SENDMAILTO="%(recipient)s"
FQDN=0
RULEDIR="%(part_dir)s"
LOCKFILE="%(var_dir)s/lock"
LOGFILES_LIST="%(part_dir)s/logcheck.logfiles"
STATEDIR="%(var_dir)s/state"
EVENTSSUBJECT="%(subject)s"
'''


class Recipe(object):
    """Recipe for installing logcheck configuration files"""

    def __init__(self, buildout, name, options):
        self.buildout, self.name, self.options = buildout, name, options
        self.buildout_dir = self.buildout['buildout']['directory']
        var_dir = os.path.abspath(
            os.path.join(self.buildout_dir, 'var', self.name))
        part_dir = os.path.abspath(
            os.path.join(self.buildout_dir, 'parts', self.name))
        state_dir = os.path.abspath(
            os.path.join(var_dir, 'state'))
        self.options['var_dir'] = var_dir
        self.options['part_dir'] = part_dir
        self.options['state_dir'] = state_dir
        self.recipient = self.options['recipient']

        self.logfiles = [f for f in self.options['logfiles'].split() if f]
        self.logfiles = [os.path.join(self.buildout_dir, f) for f in
                         self.logfiles]

        options.setdefault('subject', self.logfiles[0])
        options.setdefault('ignores', '')
        self.ignores = [i for i in self.options['ignores'].split('\n') if i]
        # File locations.
        self.generic_config = os.path.join(part_dir, 'logcheck.conf')
        self.logfiles_config = os.path.join(part_dir, 'logcheck.logfiles')
        self.ignore_file = os.path.join(part_dir,
                                        'ignore.d.workstation',
                                        '%s-ignores' % self.name)
        # Crontab command
        self.options['command'] = '/usr/sbin/logcheck -c %s' % (
            self.generic_config)

    def install(self):
        """Make sure all directories/files exist and install configuration."""
        # Make sure directories exist.
        for directory in (self.options['var_dir'],
                          self.options['state_dir'],
                          self.options['part_dir']):
            if not os.path.isdir(directory):
                os.makedirs(directory)
                logger.info('Created %s', directory)
        for needed in NEEDED_SUBDIRS:
            directory = os.path.join(self.options['part_dir'], needed)
            if not os.path.isdir(directory):
                os.makedirs(directory)
                logger.info('Created %s', directory)
        # Create config files.
        contents = CONF_TEMPLATE % dict(
            recipient=self.recipient,
            part_dir=self.options['part_dir'],
            var_dir=self.options['var_dir'],
            subject=self.options['subject'])
        open(self.generic_config, 'w').write(contents)
        contents = '\n'.join(self.logfiles)
        open(self.logfiles_config, 'w').write(contents)
        # Handle regex's
        if self.ignores:
            contents ='\n'.join(self.ignores) + '\n'
            open(self.ignore_file, 'w').write(contents)
            logger.info("Writing file with %s ignore patterns: %s",
                        len(self.ignores), self.ignore_file)
        else:
            if os.path.exists(self.ignore_file):
                os.remove(self.ignore_file)
        return tuple()

    def update(self):
        """When there are no changes, there's nothing to do."""
        pass



# -*- coding: utf-8 -*-
"""
This module contains the tool of tha.recipe.logcheck
"""
import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '1.0'

long_description = (
    read('README.txt')
    + '\n\n' +
    read('src', 'tha', 'recipe', 'logcheck', 'README.txt')
    + '\n\n' +
    read('CONTRIBUTORS.txt')
    + '\n\n' + 
    read('CHANGES.txt')
    )
entry_point = 'tha.recipe.logcheck:Recipe'
entry_points = {"zc.buildout": ["default = %s" % entry_point]}

tests_require=['zope.testing', 'zc.buildout', 'zc.recipe.egg',
               'z3c.recipe.usercrontab']

setup(name='tha.recipe.logcheck',
      version=version,
      description="Logcheck configuration recipe",
      long_description=long_description,
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Buildout',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: Zope Public License',
        ],
      keywords='',
      author='Reinout van Rees',
      author_email='reinout@vanrees.org',
      url='http://pypi.python.org/pypi/tha.recipe.logcheck',
      license='',
      package_dir={'': 'src'},
      packages=find_packages('src'),
      namespace_packages=['tha', 'tha.recipe'],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'zc.buildout',
                        # -*- Extra requirements: -*-
                        'zc.recipe.egg',
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite = 'tha.recipe.logcheck.tests.test_docs.test_suite',
      entry_points=entry_points,
      )
